@@ -16,7 +16,7 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: POM.pm,v 1.1.1.1 2001/05/17 08:49:34 abw Exp $
+#   $Id$
 #
 #========================================================================
 
@@ -30,32 +30,12 @@ use Pod::POM::Nodes;
 use Pod::POM::View::Pod;
 
 use vars qw( $VERSION $DEBUG $ERROR $ROOT $TEXTSEQ $DEFAULT_VIEW );
-use base qw( Exporter );
 
-$VERSION = 0.03;
+$VERSION = 0.1;
 $DEBUG   = 0 unless defined $DEBUG;
-$ROOT    = 'Pod::POM::Node::Pod';               # root node class
-$TEXTSEQ = 'Pod::POM::Node::Sequence';          # text sequence class
-$DEFAULT_VIEW = 'Pod::POM::View::Pod';          # default view class
-
-
-#------------------------------------------------------------------------
-# allow 'meta' to be specified as a load option to activate =meta tags
-#------------------------------------------------------------------------
-
-use vars qw( @EXPORT_FAIL @EXPORT_OK $ALLOW_META );
-@EXPORT_OK   = qw( meta );
-@EXPORT_FAIL = qw( meta );
-$ALLOW_META  = 0;
-
-sub export_fail {
-    my $class = shift;
-    my $meta  = shift;
-    return ($meta, @_) unless $meta eq 'meta';
-    $ALLOW_META++;
-    return @_;
-}
-
+$ROOT    = qw( Pod::POM::Node::Pod );		# root node class
+$TEXTSEQ = qw( Pod::POM::Node::Sequence );	# text sequence class
+$DEFAULT_VIEW = qw( Pod::POM::View::Pod );	# default view class
 
 
 #------------------------------------------------------------------------
@@ -69,9 +49,8 @@ sub new {
     bless {
 	CODE     => $config->{ code } || 0,
         WARN     => $config->{ warn } || 0,
-	META     => $config->{ meta } || $ALLOW_META,
-	WARNINGS => [ ],
 	FILENAME => '',
+	WARNINGS => [ ],
 	ERROR    => '',
     }, $class;
 }
@@ -181,14 +160,7 @@ sub parse_text {
 	    # switch on for =pod or any other =cmd, switch off for =cut
 	    if    ($type eq 'pod') { $inpod = 1; next }
 	    elsif ($type eq 'cut') { $inpod = 0; next }
-	    else                   { $inpod = 1 };
-
-	    if ($type eq 'meta') {
-		$self->{ META }
-		    ? $stack[0]->metadata(split(/\s+/, $para, 2))
-		    : $self->warning("metadata not allowed", $name, $$line);
-		next;
-	    }
+	    else                   { $inpod = 1 }
 	}
 	elsif (! $inpod) {
 	    next unless $code;
@@ -1002,23 +974,20 @@ formatting conventions.  By clearly separating the content
 (represented by one or more views) it becomes much easier to achieve
 this.
 
-The latest version of the Template Toolkit (2.06 at the time of
-writing) provides a Pod plugin to interface to this module.  It also
-implements a new (but experimental) VIEW directive which can be used
-to build different presentation styles for converting Pod to other
-formats.  The Template Toolkit is available from CPAN:
+The latest version (2.01) of the Template Toolkit provides a Pod::POM
+plugin to interface to this module.  In addition, it supports a new
+VIEW directive which allows you to define the presentation elements as
+template blocks.  At the time of writing, version 2.01 hasn't been 
+officially released to CPAN, but a preview is available from the 
+Template Toolkit web site:
 
-    http://www.cpan.org/modules/by-module/Template/
+    http://www.template-toolkit.org/
 
-Template Toolkit views are similar to the Pod::POM::View objects
-described above, except that they allow the presentation style for
-each Pod component to be written as a template file or block rather
-than an object method.  The precise syntax and structure of the VIEW
-directive is subject to change (given that it's still experimental),
-but at present it can be used to define a view something like this:
+The precise syntax and structure of the VIEW directive is subject to 
+change, but at present it can be used to define a view something like 
+this:
 
     [% VIEW myview %]
-
        [% BLOCK view_head1 %]
           <h1>[% item.title.present(view) %]</h1>
           [% item.content.present(view) %]
@@ -1035,8 +1004,7 @@ but at present it can be used to define a view something like this:
 
 A plugin is provided to interface to the Pod::POM module:
 
-    [% USE pod %]
-    [% pom = pod.parse('/path/to/podfile') %]
+    [% USE pom = Pod.POM(myfile) %]
 
 The returned Pod Object Model instance can then be navigated and
 presented via the view in almost any way imaginable:
@@ -1054,33 +1022,9 @@ presented via the view in almost any way imaginable:
        [% section.present(myview) %]
     [% END %]
 
-You can either pass a reference to the VIEW (myview) to the 
-present() method of a Pod::POM node:
-
-    [% pom.present(myview) %]	    # present entire document
-
-Or alternately call the print() method on the VIEW, passing the 
-Pod::POM node as an argument:
-
-    [% myview.print(pom) %]
-
-Internally, the view calls the present() method on the node,
-passing itself as an argument.  Thus it is equivalent to the 
-previous example.
-
-The Pod::POM node and the view conspire to "Do The Right Thing" to 
-process the right template block for the node.  A reference to the
-node is available within the template as the 'item' variable.
-
-   [% BLOCK view_head2 %]
-      <h2>[% item.title.present(view) %]</h2>
-      [% item.content.present(view) %]
-   [% END %]
-
-The Template Toolkit documentation contains further information on
-defining and using views.  However, as noted above, this may be
-subject to change or incomplete pending further development of the 
-VIEW directive.
+As noted above this is all still experimental but should stabilise
+with the release of the Template Toolkit 2.01, expected some time late
+in January 2001.  This documentation will be updated at that time.
 
 =head1 METHODS
 
@@ -1179,26 +1123,6 @@ warning message as an argument.
     my $parser = Pod::POM->new( warn => \&my_warning );
     my $podpom = $parser->parse_file($filename);
 
-=item meta
-
-The 'meta' option can be set to allow C<=meta> tags within the Pod
-document.  
-
-    my $parser = Pod::POM->new( meta => 1 );
-    my $podpom = $parser->parse_file($filename);
-
-This is an experimental feature which is not part of standard
-POD.  For example:
-
-    =meta author Andy Wardley
-
-These are made available as metadata items within the root
-node of the parsed POM.
-
-    my $author = $podpom->metadata('author');
-
-See the L<METADATA|METADATA> section below for further information.
-
 =back
 
 =head2 parse_file($file)
@@ -1278,7 +1202,7 @@ next C<=head1> tag or the end of the file.
 
 Attributes: title
 
-Content elements: head2, head3, head4, over, begin, for, verbatim, text, code.
+Content elements: head2, over, begin, for, verbatim, text, code.
 
 =item head2
 
@@ -1287,24 +1211,6 @@ next C<=head1> or C<=head2> tag or the end of the file.
 
 Attributes: title
 
-Content elements: head3, head4, over, begin, for, verbatim, text, code.
-
-=item head3
-
-A C<head3> node contains the Pod content from a C<=head3> tag up to the 
-next C<=head1>, C<=head2> or C<=head3> tag or the end of the file.
-
-Attributes: title
-
-Content elements: head4, over, begin, for, verbatim, text, code.
-
-=item head4
-
-A C<head4> node contains the Pod content from a C<=head4> tag up to the 
-next C<=head1>, C<=head2>, C<=head3> or C<=head4> tag or the end of the file.
-
-Attributes: title
-
 Content elements: over, begin, for, verbatim, text, code.
 
 =item over
@@ -1465,51 +1371,13 @@ it encounters.  The regenerated Pod output is printed to STDOUT.
 
     $ pomcheck -f My/Module.pm > newfile
 
-=head1 METADATA
-
-This module includes support for an experimental new C<=meta> tag.  This
-is disabled by default but can be enabled by loading Pod::POM with the 
-C<meta> option.
-
-    use Pod::POM qw( meta );
-
-Alternately, you can specify the C<meta> option to be any true value when 
-you instantiate a Pod::POM parser:
-
-    my $parser = Pod::POM->new( meta => 1 );
-    my $pom    = $parser->parse_file($filename);
-
-Any C<=meta> tags in the document will be stored as metadata items in the 
-root node of the Pod model created.  
-
-For example:
-
-    =meta module Foo::Bar
-
-    =meta author Andy Wardley
-
-You can then access these items via the metadata() method.
-
-    print "module: ", $pom->metadata('module'), "\n";
-    print "author: ", $pom->metadata('author'), "\n";
-
-or
-
-    my $metadata = $pom->metadata();
-    print "module: $metadata->{ module }\n";
-    print "author: $metadata->{ author }\n";
-
-Please note that this is an experimental feature which is not supported by
-other POD processors and is therefore likely to be most incompatible.  Use
-carefully.
-    
 =head1 AUTHOR
 
 Andy Wardley E<lt>abw@kfs.orgE<gt>
 
 =head1 VERSION
 
-This is version 0.3 of the Pod::POM module.
+This is version 0.1 of the Pod::POM module.
 
 =head1 COPYRIGHT
 
